#!/usr/bin/perl -w

#-------------------------------------------
# Copyright (c) Craig D. Jensen 2004-2007
# Genweb Administration panel
#-------------------------------------------
package	esmith::FormMagick::Panel::geneweb;

use strict;
use warnings;

use esmith::FormMagick;
use esmith::ConfigDB;
use esmith::HostsDB;
use esmith::util;

use File::Basename;
use Exporter;

our @ISA = qw(esmith::FormMagick Exporter);

our @EXPORT = qw(
    get_prop
);

our $VERSION = sprintf '%d.%03d', q$Revision: 0.09 $ =~ /: (\d+).(\d+)/;

our $cdb = esmith::ConfigDB->open || die "Couldn't open Configuration DB\n";

our $REGEXP_DOMAIN = qq([a-zA-Z0-9\-\.]+);


sub new {
        shift;
        my $self = esmith::FormMagick->new();
        $self->{calling_package} = (caller)[0];
        bless $self;
	#$self->debug(1);
	return $self;
}


sub get_prop {
	my $fm = shift if (ref($_[0]) );
	my $item = shift;
	my $prop = shift;
	
	my $record = $cdb->get($item);
	if ($record) {
	    return $record->prop($prop);
	}
	else {
	    return '';
	}
}


sub get_dbdir {
        return $cdb->get_prop("geneweb", "DBDir");
}


sub get_geneweb_st {
        return $cdb->get_prop("geneweb", "status");
}


sub get_geneweb_ac {
        return $cdb->get_prop("geneweb", "access");
}


sub get_gwsetup_st {
        return $cdb->get_prop("gwsetup", "status");
}


sub get_gwsetup_ac {
        return $cdb->get_prop("gwsetup", "access");
}


sub change_settings {

	my $self = shift;
	my $q = $self->{'cgi'};
	
	my $n_gw_dbdir	= $q->param("geneweb_dbdir") || '';
	my $n_gw_st	= $q->param("geneweb_st");
	my $n_gw_ac	= $q->param("geneweb_ac");

	my $n_gws_st	= $q->param("gwsetup_st");
	my $n_gws_ac	= $q->param("gwsetup_ac");

	my $gw_dbdir	= get_dbdir();
	my $gw_st	= get_geneweb_st();
	my $gw_ac	= get_geneweb_ac();

	my $gws_st	= get_gwsetup_st();
	my $gws_ac	= get_gwsetup_ac();

	if ( ($n_gw_dbdir eq $gw_dbdir) && ($n_gw_st eq $gw_st) 
	    && ($n_gw_ac eq $gw_ac) && ($n_gws_st eq $gws_st) && ($n_gws_ac eq $gws_ac) ) {
	    return $self->success("NO_CHANGE");
	}
	if ($n_gw_dbdir) { $cdb->set_prop("geneweb", "DBDir", $n_gw_dbdir) };

	$cdb->set_prop("geneweb", "status", $n_gw_st);
	$cdb->set_prop("geneweb", "access", $n_gw_ac);

	$cdb->set_prop("gwsetup", "status", $n_gws_st);
	$cdb->set_prop("gwsetup", "access", $n_gws_ac);
	
        return ( system ( "/sbin/e-smith/signal-event", "geneweb-modify" ) ) ?
	    $self->error("ERROR_UPDATING") : $self->success("SUCCESS");
}


sub dir_must_exist {

    my $self = shift;
    my $q = $self->{cgi};

    my $gw_dbdir = $q->param("geneweb_dbdir") || '';
    $gw_dbdir = $1 if ($gw_dbdir =~ /^($REGEXP_DOMAIN)$/);
    return 'ERR_DIR_NOT_EXIST' unless ($gw_dbdir);

    if ($gw_dbdir) {
	if ( ! -d "$gw_dbdir" ) {
	    return $self->localise('ERR_DIR_NOT_EXIST');
	} 
    }
    return 'OK';
}


sub get_stat_gwd {

	my $fm = shift;
	if ( get_geneweb_st() eq 'enabled' 
	&& system ( "/bin/ps cax | /bin/grep 'gwd' > /dev/null") != 0 ) {
	    return $fm->localise('ERROR_STATUS_GENEWEB');
	}
	if ( get_geneweb_st() eq 'disabled' 
	&& system ( "/bin/ps cax | /bin/grep 'gwd' > /dev/null") == 0 ) {
	    return $fm->localise('ERROR2_STATUS_GENEWEB');
	}
	return '';
}


sub get_stat_gws {

	my $fm = shift;
	if ( get_gwsetup_st() eq 'enabled' 
	&& system ( "/bin/ps cax | /bin/grep 'gwsetup' > /dev/null") != 0 ) {
	    return $fm->localise('ERROR_STATUS_GWSETUP');
	}
	if ( get_gwsetup_st() eq 'disabled' 
	&& system ( "/bin/ps cax | /bin/grep 'gwsetup' > /dev/null") == 0 ) {
	    return $fm->localise('ERROR2_STATUS_GWSETUP');
	}
	return '';
}


1;
